/*
Copyright (c) 2000                      RIPE NCC


All Rights Reserved

Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of the author not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS; IN NO EVENT SHALL
AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

/*
-------------------------------------------------------------------------------
Module Header
Filename          : delayplots.C
Author            : Rene Wilhelm
Date              : 17-DEC-2000
Description       : Main program for creating TTM delay plots
Language Version  : C++
OSs Tested        : Linux gcc 3.0
Command line 
    required args : -p <timeperiod>	iso8601 format time period for stats
    optional args : -s source_id	numeric id of source box
		    -t target_id	numeric id of target box

$Id: delayplots.C,v 1.3 2003/05/16 13:57:41 ttraffic Exp $
-------------------------------------------------------------------------------
*/

#include <TROOT.h>
#include <TApplication.h>
#include <TFile.h>

#include <iostream.h>
#include <stdlib.h>
#include "TTMDelayData.h"
#include "TTMOptions.h"
#include "TestBoxConfig.h"

static char const rcsid[] = "$Id: delayplots.C,v 1.3 2003/05/16 13:57:41 ttraffic Exp $";
static char const *rcsid_p = rcsid;   // Prevent g++ from optimizing out rcsid

int main (int argc, char **argv) {


// fetch options and set defaults


// Initialize ROOT system

	TROOT simple ("TTM", "Delayplots");
	gROOT->SetBatch();		// no graphics windows

	TApplication theApp("Delayplots", NULL, NULL);


// now we can start ...

        TTMOptions options(argc, argv, "6af:m:o:p:s:t:vz:");

        TestBoxConfig config(options);
	TTMDelayData data;
	data.SetConfig(options, config, 0);

	// plot or output CSV

	if (options.PlotFormat() == csv) {
		data.OutputCSV();
	}
	else {
		data.Plot();
	}

	return(0);
}
